function [ decoded_sbd, sbd_messages_info ] = decode_float( p_config, p_imei )
%DECODE_FLOAT Decodes the sbd messages of the floats that match the given IMEI.
%
%   Parameters:
%   p_config:           The nemo configuration.
%   p_imei:             The IMEI of the float to be decoded.
%
%   Returns:
%   decoded_sbd:        The decoded sbd messages.
%   sbd_messages_info:  The information about the sbd messages.

%% Initialize return value
decoded_sbd = false;
sbd_messages_info = false;

%% Create filepath string
sbd = ['sbd' p_config.GENERAL.folder_separator];
if (~ischar(p_imei))
    imei = int2str(p_imei);
else
    imei = p_imei;
end
    
filepath = p_config.MAIL.storage_directory;

% Do not change the order of the next two if conditions!
if (p_config.MAIL.sort_by_imei)
    filepath = [filepath imei p_config.GENERAL.folder_separator];
end
if (p_config.MAIL.separate_sbd_and_txt)
    filepath = [filepath sbd];
end

if (p_config.MAIL.sort_by_imei)
    [decoded_sbd,~,sbd_messages_info] = nemo.optimare.process_moms(filepath);
else
    [decoded_sbd,~,sbd_messages_info] = nemo.optimare.process_moms(filepath, imei);
end

end

